Documentation
¶
Index ¶
Constants ¶
const (
TotalTasksCount = 2
)
Variables ¶
var (
DefaultPaginationLimit = 500
)
Functions ¶
This section is empty.
Types ¶
type DatasetEditionMetadata ¶ added in v0.6.0
type DatasetEditionMetadata struct {
// contains filtered or unexported fields
}
type ReindexRequestedHandler ¶
type ReindexRequestedHandler struct {
ZebedeeCli clients.ZebedeeClient
DatasetAPICli clients.DatasetAPIClient
ContentUpdatedProducer event.ContentUpdatedProducer
ReindexTaskCountsProducer event.ReindexTaskCountsProducer
Config *config.Config
}
ReindexRequestedHandler is the handler for reindex requested messages.
func (*ReindexRequestedHandler) Handle ¶
func (h *ReindexRequestedHandler) Handle(ctx context.Context, reindexReqEvent *models.ReindexRequested)
Handle takes a single event. TODO - any error which occurs in the ReindexRequestedHandler.Handle function are not returned and only logged We are only logging as we are not handling errors via an error topic yet
Click to show internal directories.
Click to hide internal directories.